.. _how-to-guides:

How-to guides
=============

.. toctree::
   :maxdepth: 2

   set-up-charmcraft
   manage-charms
   manage-a-12-factor-app-charm
   manage-extensions
   manage-resources
   manage-libraries
   manage-parts
   manage-the-current-charmhub-user
   manage-names
   manage-revisions
   manage-channels
   manage-tracks
   manage-icons
   manage-bundles
   flask-async
   Migrate plugins <migrate-plugins/index>
   Build <build-guides/index>
